@@ -23,7 +23,8 @@ from elasticsearch_dsl.field import (
     Object,
     Short,
     Keyword,
-    Text
+    Text,
+    SearchAsYouType,
 )
 
 from .exceptions import VariableLookupError
@@ -115,6 +116,11 @@ class ObjectField(DEDField, Object):
                     obj, field_value_to_ignore
                 )
 
+        # This allows for ObjectFields to be indexed from dicts with
+        # dynamic keys (i.e. keys/fields not defined in 'properties')
+        if not data and obj and isinstance(obj, dict):
+            data = obj
+
         return data
 
     def get_value_from_instance(self, instance, field_value_to_ignore=None):
@@ -124,7 +130,14 @@ class ObjectField(DEDField, Object):
 
         if objs is None:
             return {}
-        if isinstance(objs, collections.Iterable):
+        try:
+            is_iterable = bool(iter(objs))
+        except TypeError:
+            is_iterable = False
+
+        # While dicts are iterable, they need to be excluded here so
+        # their full data is indexed
+        if is_iterable and not isinstance(objs, dict):
             return [
                 self._get_inner_field_data(obj, field_value_to_ignore)
                 for obj in objs if obj != field_value_to_ignore
@@ -201,6 +214,18 @@ class ShortField(DEDField, Short):
     pass
 
 
+class KeywordField(DEDField, Keyword):
+    pass
+
+
+class TextField(DEDField, Text):
+    pass
+
+
+class SearchAsYouTypeField(DEDField, SearchAsYouType):
+    pass
+
+
 class FileFieldMixin(object):
     def get_value_from_instance(self, instance, field_value_to_ignore=None):
         _file = super(FileFieldMixin, self).get_value_from_instance(
@@ -211,13 +236,5 @@ class FileFieldMixin(object):
         return _file if _file else ''
 
 
-class KeywordField(DEDField, Keyword):
-    pass
-
-
-class TextField(DEDField, Text):
-    pass
-
-
 class FileField(FileFieldMixin, DEDField, Text):
     pass
